# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-YAML-Syck
Version:	1.34
Release:	13.%{__distinit}%{__distvers}
Summary:	Fast, lightweight YAML loader and dumper
# gram.*:	GPL-2.0-or-later
# *:		MIT
# Note that libsyck COPYING file describes itself as BSD but it's actually MIT
License:	GPL-2.0-or-later AND MIT
URL:		https://metacpan.org/release/YAML-Syck
Source0:	https://cpan.metacpan.org/modules/by-module/YAML/YAML-Syck-%{version}.tar.gz
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	gcc
BuildRequires:	make
BuildRequires:	perl-devel
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
# Dependencies of bundled ExtUtils::HasCompiler
BuildRequires:	perl(base)
BuildRequires:	perl(Carp)
BuildRequires:	perl(Config)
BuildRequires:	perl(DynaLoader)
BuildRequires:	perl(ExtUtils::Mksymlists)
BuildRequires:	perl(File::Basename)
BuildRequires:	perl(File::Spec::Functions)
BuildRequires:	perl(File::Temp)
# Module Runtime
BuildRequires:	perl(constant)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(strict)
BuildRequires:	perl(vars)
BuildRequires:	perl(XSLoader)
# Test Suite
BuildRequires:	perl(Data::Dumper)
BuildRequires:	perl(FindBin)
BuildRequires:	perl(IO::File)
BuildRequires:	perl(Storable)
BuildRequires:	perl(Test::More)
BuildRequires:	perl(Tie::Hash)
BuildRequires:	perl(utf8)
BuildRequires:	perl(warnings)
# Optional Tests
BuildRequires:	perl(Devel::Leak)
BuildRequires:	perl(JSON)
BuildRequires:	perl(Symbol)
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif

# Avoid provides for private perl objects
%{?perl_default_filter}

%description
This module provides a Perl interface to the libsyck data serialization
library. It exports the Dump and Load functions for converting Perl data
structures to YAML strings, and the other way around.

%prep
%setup -q -n YAML-Syck-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags} -DI_STDLIB=1 -DI_STRING=1"
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
find %{buildroot} -type f -name '*.bs' -empty -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%license COPYING
%doc Changes COMPATIBILITY README.md
%{perl_vendorarch}/auto/YAML/
%{perl_vendorarch}/YAML/
%{perl_vendorarch}/JSON/
%{_mandir}/man3/JSON::Syck.3*
%{_mandir}/man3/YAML::Syck.3*

%changelog
* Thu Jun 13 2024 Paul Howarth <paul@city-fan.org> - 1.34-13
- Perl 5.40 rebuild

* Wed Jul 12 2023 Paul Howarth <paul@city-fan.org> - 1.34-9
- Perl 5.38 rebuild

* Thu May 18 2023 Paul Howarth <paul@city-fan.org> - 1.34-8
- Use SPDX-format license tag

* Wed Jun  1 2022 Paul Howarth <paul@city-fan.org> - 1.34-6
- Perl 5.36 rebuild

* Sat May 22 2021 Paul Howarth <paul@city-fan.org> - 1.34-3
- Perl 5.34 rebuild

* Tue Oct 27 2020 Paul Howarth <paul@city-fan.org> - 1.34-1
- Update to 1.34
  - Fix memory corruption (GH#44, GH#48)
  - Fix for handling circular aliases (GH#52, GH#53)
  - Unconditionally include stdlib.h in syck.h (GH#56)
  - Switch changelog to a more parsable format
  - Update github CI to use a cpanfile
  - Update Devel::PPPort to 3.62
  - Stop depending on constants dropped from Perl 5.28 (GH#50)

* Fri Jun 26 2020 Paul Howarth <paul@city-fan.org> - 1.32-2
- Perl 5.32 rebuild

* Tue Jan 28 2020 Paul Howarth <paul@city-fan.org> - 1.32-1
- Update to 1.32
  - Interface Change: Change default for LoadBlessed to false
  - Remove YAML::Syck tests that parse META.yml
  - Switch to github actions for testing
  - Remove 'use vars' from code in favour of 'our'

* Sun Jun  2 2019 Paul Howarth <paul@city-fan.org> - 1.31-3
- Perl 5.30 rebuild

* Fri Oct 26 2018 Paul Howarth <paul@city-fan.org> - 1.31-1
- Update to 1.31
  - Switch to ExtUtils::MakeMaker for builder
  - Switch official issue tracker and repo to github
  - MANIFEST warning is now fixed; also shipping additional tests because of
    this
- Make sure <stdlib.h> and <string.h> are included, quietens lots of warnings

* Thu Jun 28 2018 Paul Howarth <paul@city-fan.org> - 1.30-6
- Perl 5.28 rebuild

* Fri Aug  4 2017 Paul Howarth <paul@city-fan.org> - 1.30-4
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl

* Sun Jun 11 2017 Paul Howarth <paul@city-fan.org> - 1.30-2
- Perl 5.26 rebuild

* Thu Apr 20 2017 Paul Howarth <paul@city-fan.org> - 1.30-1
- Update to 1.30
  - Fix handling carriage return after c-indicator (CPAN RT#41141)
  - Fix CHECK_UTF8 SEGV with empty len=0 strings (CPAN RT#61562)
  - Add missing function declarations
  - Tighten the TODO tests; no passing TODOs now, but still JSON
  - SingleQuote and \/ and \u roundtrips do fail
- Drop support for EOL distributions prior to F-13
  - Drop Group: and BuildRoot: tags
  - Drop buildroot cleaning in %%install
  - Drop explicit %%clean section
  - Drop workaround for Perl < 5.10

* Mon Oct 17 2016 Paul Howarth <paul@city-fan.org> - 1.29-6
- Fix FTBFS when perl is not in the minimal buildroot
- BR: perl-devel and perl-generators where available
- Simplify find commands using -empty and -delete

* Tue Dec 16 2014 Paul Howarth <paul@city-fan.org> - 1.29-1
- Update to 1.29
  - Upstreamed fix for test failures on PPC and ARM (CPAN RT#83825)
  - Fix crash in syck_emit on platforms with long long pointers

* Thu Dec 11 2014 Paul Howarth <paul@city-fan.org> - 1.28-1
- Update to 1.28
  - Update inc modules to avoid precedence warnings in newer perl
    (CPAN RT#87034)
- Classify buildreqs by usage

* Thu Aug 28 2014 Paul Howarth <paul@city-fan.org> 1.27-6
- Drop %%defattr, redundant since rpm 4.4
- Use %%license where possible

* Tue Jul 16 2013 Paul Howarth <paul@city-fan.org> 1.27-2
- Perl 5.18 rebuild

* Tue May 21 2013 Paul Howarth <paul@city-fan.org> 1.27-1
- Update to 1.27
  - Fix for hash randomization in yaml-alias.t on perl 5.18.0 (CPAN RT#84882,
    CPAN RT#84466)

* Mon Mar 11 2013 Paul Howarth <paul@city-fan.org> 1.25-1
- Update to 1.25
  - Bump version number and release to fix a MANIFEST mistake in 1.24
- Work around test failures on PPC and ARM (#919806, CPAN RT#83825)

* Thu Mar  7 2013 Paul Howarth <paul@city-fan.org> 1.24-1
- Update to 1.24
  - Implement $JSON::Syck::MaxDepth
  - Prevent failure when the same object is seen twice during Dump
  - Prevent YAML from being influenced by the previous change
  - MinGW64 compatibility (CPAN RT#78363)

* Wed Feb 27 2013 Paul Howarth <paul@city-fan.org> 1.23-1
- Update to 1.23
  - Make sure that LoadBlessed=0 blocks all blessing
  - Start listing primary repo as http://github.com/toddr/YAML-Syck
  - README refreshed via perldoc -t

* Wed Dec  5 2012 Paul Howarth <paul@city-fan.org> 1.22-1
- Update to 1.22
  - Fix error message typo: s/existant/existent/g
  - Fix for non-printable character detection
  - Quote if non-printable characters are present
  - Change LoadBlessed=0 to not bless under ANY circumstances

* Fri Sep 21 2012 Paul Howarth <paul@city-fan.org> 1.21-1
- Update to 1.21
  - Synchronize JSON::Syck with YAML::Syck version number
  - Add DumpInto functions (YAML+Syck), which dump into a provided scalar
    instead of a newly-allocated one
  - Modify DumpFile functions to output directly to the specified
    file/filehandle instead of buffering all output in memory
  - Avoid modifying numbers into strings when emitting
- Update Perl RT#102606 patch

* Sun Jun 24 2012 Paul Howarth <paul@city-fan.org> 1.20-2
- BR:/R: perl(XSLoader)
- BR: perl(constant), perl(Cwd), perl(Data::Dumper), perl(Exporter),
  perl(IO::File) and perl(Storable)
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorarch}
  - Use DESTDIR rather than PERL_INSTALL_ROOT
  - Use %%{_fixperms} macro rather than our own chmod incantation

* Wed Feb 15 2012 Paul Howarth <paul@city-fan.org> 1.20-1
- Update to 1.20
  - Add test to assure META.yml is up to date before release
  - Disable check for empty file handle in LoadFile calls (CPAN RT#70933)
  - Remove call to non-existent code YAML::Syck::_is_openhandle
  - Compiling with -Werror=format-security failed (CPAN RT#74785)
- This release by TODDR -> update source URL

* Tue Nov  8 2011 Paul Howarth <paul@city-fan.org> 1.19-1
- Update to 1.19
  - Do not run t/leak.t on perls prior to 5.8.9 as 5.8.8 and Devel::Leak
    apparently do not mix (Perl RT #102606)
- Add patch to reinstate t/leak.t on old perls, as it works just fine with our
  patch for 1.18

* Sun Nov  6 2011 Paul Howarth <paul@city-fan.org> 1.18-1
- Update to 1.18
  - Break YAML::Syck dependency on Scalar::Util
  - Only lvalue subroutines are supposed to return the argument to "return"
    without copying it; stop relying on a pre-5.15 bug (Perl RT#102606)
- Add patch to revert fix for Perl RT#102606 with Perl < 5.10.0, as it breaks
  t/leak.t
- This release by SMUELLER -> update source URL

* Thu Jun 23 2011 Paul Howarth <paul@city-fan.org> 1.17-3
- Rebuild for perl 5.14.1 in Rawhide
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Mon Nov 22 2010 Paul Howarth <paul@city-fan.org> 1.17-1
- Update to 1.17
  - Change a C99 comment to a C89 comment
  - Upgrade ppport.h from 3.13 to 3.19
  - Remove inc/Test/Builder/IO/Scalar.pm from MANIFEST
  - POD formatting fixes contributed by Justin Hunter

* Fri Oct  1 2010 Paul Howarth <paul@city-fan.org> 1.15-2
- Rebuild for gcc bug (#634757)

* Fri Sep 24 2010 Paul Howarth <paul@city-fan.org> 1.15-1
- Update to 1.15 (fix test breakage in 5.13.5 onwards due to changes in the
  way regexes are stringified - Perl RT#78008)
- This release by AVAR -> update source URL

* Fri Aug 27 2010 Paul Howarth <paul@city-fan.org> 1.14-1
- Update to 1.14
  - Quoting fixes for JSON with numbers (CPAN RT#60771)
  - Add YAML tests to make sure HEX and octal preserve their information

* Thu Aug  5 2010 Paul Howarth <paul@city-fan.org> 1.12-1
- Update to 1.12
  - Make tie test a TODO test
- Drop patch for tie test (CPAN RT#60064), no longer needed

* Wed Aug  4 2010 Paul Howarth <paul@city-fan.org> 1.11-1
- Update to 1.11
  - Test load of in-memory file handles
  - Perl 5.8 required to YAML-ify code refs
  - Perl 5.6 requires {} to print to a scalar GLOB
  - Use SvNIOK to test for int or float if we know it's not a string
  - Skip failing tie test on perl < 5.8.8 && perl >= 5.7.0x
  - Fix CPAN RT#23850 - parse META.yml of DateTime::Format::Japanese 0.01
  - Fix CPAN RT#34073 - TODO Tests - Parsing YAML without separator
  - Fix CPAN RT#20969 - document die behavior differences with YAML
  - Fix CPAN RT#23909 - loaded self-referring document is corrupted
  - Fix CPAN RT#50227 - logic bug in deciding what numbers to quote
  - Fix CPAN RT#59458 - convert \%%d to \%%ld to prevent compiler warnings
  - Fix CPAN RT#50227 - string quoting issue
  - Fix CPAN RT#48327 - use 3-arg form of open()
  - Fix CPAN RT#59432 - use lexical file handles for read/write to files
  - Fix CPAN RT#37236 - re-enable JSON-basic tests for JSON >= 2.11
  - Fix CPAN RT#47944 - backquote is a reserved character
  - Fix CPAN RT#36288 - ability to disable blessing data structures on load
  - LoadFile aborts loading an empty file
  - Add TODO tests for noted deficiencies in RT #'s 26182, 54780, 49404, 42390
  - Add TODO tests for CPAN RT#52432 - '... X' breaks round trip
  - Tone down the WARNING section in YAML::Syck's documentation added in 1.08
- This release by TODDR -> update source URL
- Add patch for failing tie test on perl 5.8.8 (CPAN RT#60064)

* Wed Jun 23 2010 Paul Howarth <paul@city-fan.org> 1.10-2
- Rebuild for perl 5.12.1 in Rawhide

* Mon Jun  7 2010 Paul Howarth <paul@city-fan.org> 1.10-1
- Update to 1.10 (bump Module::Install to 0.99)
- Drop patch for Module::Install breakage, no longer needed

* Tue Jun  1 2010 Paul Howarth <paul@city-fan.org> 1.09-1
- Update to 1.09
  - Reset the hash iterator after dumping hashes (CPAN #54167, CPAN RT #34166)
  - Only print compat warning if 0.60 or earlier installed (CPAN RT #39572)

* Mon May 24 2010 Paul Howarth <paul@city-fan.org> 1.08-1
- Update to 1.08
  - POD link to JSON::XS from JSON::Syck
  - Add warning in YAML::Syck pod that the module is abandonware
  - Strings starting with : are now always quoted
  - Upgrade from Module::Install 0.68 to 0.97
  - Bump included Test::More dependency
  - Remove included inc/attributes.pm dependency
  - Add homepage, bugtracker, and repository metadata to META.yml
  - Bump perl dependency from 5.00307 to 5.006
- This release by AVAR -> update source URL
- Patch bundled Module::Install to work with perl < 5.9.1

* Wed May 12 2010 Paul Howarth <paul@city-fan.org> 1.07-5
- Fix dist tag for RHEL-6 Beta

* Tue Dec 22 2009 Paul Howarth <paul@city-fan.org> 1.07-4
- Import from Fedora

* Mon Dec  7 2009 Stepan Kasal <skasal@redhat.com> 1.07-3
- Rebuild against perl 5.10.1

* Tue Oct  6 2009 Marcela Mašláňová <mmaslano@redhat.com> 1.07-2
- Fix license

* Sun Sep 27 2009 Chris Weyl <cweyl@alumni.drew.edu> 1.07-1
- Auto-update to 1.07 (by cpan-spec-update 0.01)

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> 1.05-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> 1.05-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Mon Jun 09 2008 Steven Pritchard <steve@kspei.com> 1.05-1
- Update to 1.05

* Mon Mar  3 2008 Tom "spot" Callaway <tcallawa@redhat.com> 1.04-2
- Rebuild for new perl (again)

* Wed Feb 20 2008 Steven Pritchard <steve@kspei.com> 1.04-1
- Update to 1.04

* Tue Feb 19 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 1.01-3
- Autorebuild for GCC 4.3

* Fri Feb  8 2008 Tom "spot" Callaway <tcallawa@redhat.com> 1.01-2
- Rebuild for new perl

* Mon Jan 28 2008 Steven Pritchard <steve@kspei.com> 1.01-1
- Update to 1.01

* Tue Oct 16 2007 Steven Pritchard <steve@kspei.com> 0.98-1
- Update to 0.98

* Tue Sep 18 2007 Steven Pritchard <steve@kspei.com> 0.97-1
- Update to 0.97

* Sun Aug 12 2007 Steven Pritchard <steve@kspei.com> 0.96-1
- Update to 0.96

* Fri Aug 03 2007 Steven Pritchard <steve@kspei.com> 0.95-1
- Update to 0.95

* Fri Jul 13 2007 Steven Pritchard <steve@kspei.com> 0.94-1
- Update to 0.94

* Wed Jun 27 2007 Steven Pritchard <steve@kspei.com> 0.91-1
- Update to 0.91

* Sat May 19 2007 Steven Pritchard <steve@kspei.com> 0.85-1
- Update to 0.85

* Fri May 04 2007 Chris Weyl <cweyl@alumni.drew.edu> 0.82-3
- Add perl split BR's

* Fri May 04 2007 Chris Weyl <cweyl@alumni.drew.edu> 0.82-2
- Bump

* Thu Feb 01 2007 Steven Pritchard <steve@kspei.com> 0.82-1
- Specfile autogenerated by cpanspec 1.69.1
- Remove explicit build dependency on perl
- Include JSON module
- BR Devel::Leak (for tests)
